@@ -44,4 +44,4 @@ var layout = {
 }
 ;
 
-plasma.loadSerializedLayout(layout);
+plasmashell.loadSerializedLayout(layout);
